Discover Packages
github.com/4aykovski/effective_mobile_test_task
pkg
client
carinfo
package
Version:
v0.0.0-...-bfeb8cb
Opens a new window with list of versions in this module.
Published: Apr 20, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type CarInfo struct {
RegNumber string `json:"regNum"`
Mark string `json:"mark"`
Model string `json:"model"`
Year int `json:"year,omitempty"`
Owner Owner `json:"owner"`
}
type Owner struct {
Name string `json:"name"`
Surname string `json:"surname"`
Patronymic string `json:"patronymic,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.